@@ -10,7 +10,8 @@
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2, or (at your option) any
-   later version. 
+   later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -247,7 +248,7 @@ if (OptionIs(CONTEXTID,"ChecksumPurge", true))
    ChecksumPurge();
    }
 
-RecordClassUsage(CLASSHISTORY);
+RecordClassUsage();
 SummarizeObjects();
 CloseAuditLog();
 closelog();
@@ -321,7 +322,7 @@ for (i = 1, j = 1; i < argc; i++)
 
 /* Allocate memory for cfargv. */
 
-cfargv = (char **) malloc(sizeof(char *) * cfargc + 1);
+cfargv = (char **) malloc(sizeof(char *) * (cfargc + 1));
 
 if (!cfargv)
    {
@@ -1036,7 +1037,7 @@ if (OptionIs(CONTEXTID,"ShowActions",true))
    SHOWACTIONS = true;
    }
 
- if (GetMacroValue(CONTEXTID,"Umask"))
+if (GetMacroValue(CONTEXTID,"Umask"))
    {
    mode_t val;
    val = (mode_t)atoi(GetMacroValue(CONTEXTID,"Umask"));
